--------------------------------------------------------------------
-- PLG Common Functions
--------------------------------------------------------------------

---------------------------
-- set frame text
---------------------------
function PLG:setText(fs,text,s1,s2)
	_G["PLG_"..fs]:SetFormattedText(tostring(text),s1,s2)
end

---------------------------
-- send/set messages
---------------------------
function PLG:sendMSG(text)
	print(PLG.colors.BLUE..PLG.labels.NAME..":|r "..tostring(text))
end

---------------------------
-- debugging messages
---------------------------
function PLG:Debug(text,val)
	if PLG.verbose then
		print(PLG.colors.BLUE..PLG.labels.NAME..":|r "..tostring(text)..": "..tostring(val))
	end
end

---------------------------
-- tooltip text
---------------------------
function PLG:Tooltip(text1,text2,color1,color2,wrap)
	local RGB = PLG.colors.RGB
	if text1 and not color1 then -- title
		PLG.tooltip:SetText(text1, RGB["GLD"])
	elseif text1 and not text2 then -- line/wrap
		wrap = wrap or 0
		local r,g,b = unpack(RGB[color1])
		PLG.tooltip:AddLine(text1, r, g, b, wrap)
	elseif text2 and color2 then -- double
		local r,g,b = unpack(RGB[color1])
		local r2,g2,b2 = unpack(RGB[color2])
		PLG.tooltip:AddDoubleLine(text1, text2, r, g, b, r2, g2, b2)
	elseif not text1 then -- space
		PLG.tooltip:AddLine(" ", RGB["GLD"])
	end
end

---------------------------
-- create text
---------------------------
function PLG:createText(anchor,name,x,y,w,text,font,color)
	local fs = anchor:CreateFontString(name, "ARTWORK", font)
	if PLG.UseFrame then
		fs:SetPoint("TOPLEFT", 9+x, -16+y)
	else
		fs:SetPoint("TOPLEFT", 16+x, -16+y)
	end
	fs:SetHeight(40)
	fs:SetWidth(w)
	fs:SetNonSpaceWrap(true)
	fs:SetWordWrap(true)
	fs:SetJustifyH("LEFT")
	fs:SetJustifyV("TOP")
	fs:SetText(color..text)
	return fs
end

---------------------------
-- create the icons
---------------------------
function PLG:createIcon(name,x,y)
	PLG[name] = CreateFrame("BUTTON", "PLG_"..name.."_Button", PLG.frame)
	if PLG.UseFrame then x = x-7 end
	PLG[name]:SetPoint("TOPLEFT", PLG.frame, "TOPLEFT", x, y)	
	PLG[name]:SetWidth(35)
	PLG[name]:SetHeight(35)
	PLG[name]:SetFrameStrata("MEDIUM")
	PLG[name].texture = PLG[name]:CreateTexture(nil, "BACKGROUND")
	PLG[name].texture:SetTexture(0, 0, 0, 0)
	PLG[name].texture:SetAllPoints(PLG[name])
end

---------------------------
-- ? = T : F
---------------------------
function PLG:getCondition(condition, t, f)
	if condition then return t else return f end
end