--------------------------------------------------------------------
-- PLG Display Functions
--------------------------------------------------------------------

---------------------------
-- set, reset recipe
---------------------------
function PLG:setRecipe(id,name,color,icon,link)
	PLG:Debug("Function","setRecipe"..id..": "..tostring(link))
	color = color or PLG.colors.ORANGE -- default color
	if id ~= PLG.selectedRecipe then -- gray for alternate
		color = PLG.colors.GRAY
	end	
	if name then -- set name
		if id==1 then -- set recipe title
			PLG:setText("Recipe"..id.."_Title",PLG.labels.RECIPE)
		else -- set alternate title
			PLG:setText("Recipe"..id.."_Title",PLG.labels.ALTERNATE)
		end
		PLG:setText("Recipe"..id.."_Text",color..name)
	else
		PLG:setText("Recipe"..id.."_Title","")
		PLG:setText("Recipe"..id.."_Text","")
	end
	if icon then -- set icon
		PLG["Recipe"..id].texture:SetTexture(icon)		
		if id ~= PLG.selectedRecipe then -- shade when not selected
			PLG["Recipe"..id].texture:SetVertexColor(0.5, 0.5, 0.5)
		else
			PLG["Recipe"..id].texture:SetVertexColor(1, 1, 1)
		end
		if link then -- set link
			PLG["Recipe"..id]:SetScript("OnEnter",function() 
				GameTooltip:SetOwner(PLG["Recipe"..id], "ANCHOR_TOPLEFT");
				GameTooltip:SetHyperlink(link);				
				if id ~= PLG.selectedRecipe then -- cursor and click note on alternate
					SetCursor("CAST_CURSOR")
					GameTooltip:AddLine(PLG.labels.SELECT,1,1,1,0)
				end
				GameTooltip:Show(); 
			end)
			PLG["Recipe"..id]:SetScript("OnLeave",function() 
				SetCursor("POINT_CURSOR")
				GameTooltip:Hide() 
			end)			
		else -- no link
			PLG["Recipe"..id]:SetScript("OnEnter",function() end)
		end
		if (PLG["Recipe1"].texture:GetTexture() and PLG["Recipe2"].texture:GetTexture())then -- two recipes, add onclick
			PLG["Recipe1"]:SetScript("OnClick",function() 
				PLG.selectedRecipe = 1
				PLG:Update()
			end)
			PLG["Recipe2"]:SetScript("OnClick",function() 
				PLG.selectedRecipe = 2
				PLG:Update()
			end)
		end
	else -- no icon
		PLG["Recipe"..id].texture:SetTexture(nil)
		PLG["Recipe"..id]:SetScript("OnEnter",function() end)
	end
end

---------------------------
-- set, reset reagent
---------------------------
function PLG:setReagent(id,text,count,icon,link)
	PLG:Debug("Function","setReagent"..id..": "..tostring(link))
	if icon then -- set the icon
		_G["PLG_Reagent"..id.."_Button"]:SetNormalTexture(icon)
		if link then -- set the tooltip
			_G["PLG_Reagent"..id.."_Button"]:SetScript("OnEnter",function() 
				GameTooltip:SetOwner(_G["PLG_Reagent"..id.."_Button"], "ANCHOR_TOPLEFT");
				GameTooltip:SetHyperlink(link);
				GameTooltip:Show(); 
			end)
			_G["PLG_Reagent"..id.."_Button"]:SetScript("OnLeave",function() 
				GameTooltip:Hide() 
			end)
		else -- no tooltip, kill onenter
			_G["PLG_Reagent"..id.."_Button"]:SetScript("OnEnter",function() end)
		end
		PLG:setText("Reagent_Title",PLG.labels.REAGENTS)
	else -- no icon
		PLG:setText("Reagent_Title","")
		_G["PLG_Reagent"..id.."_Button"]:SetNormalTexture(nil)
		_G["PLG_Reagent"..id.."_Button"]:SetScript("OnEnter",function() end)
	end
	if text then -- set text
		if count then -- set count
			PLG:setText("Reagent"..id.."_Text",text.."\n("..count..")")
		else
			PLG:setText("Reagent"..id.."_Text",text)
		end
	else -- no text
		PLG:setText("Reagent"..id.."_Text","")
	end
end

---------------------------
-- reset the text and icons
---------------------------
function PLG:resetDisplay()
	PLG:setRecipe(1,nil,nil,nil,nil)
	PLG:setRecipe(2,nil,nil,nil,nil)
	PLG:resetTooltip()
	for j=1,8 do
		PLG:setReagent(j,nil,nil,nil)
	end
	PLG:setText("Trainer","")
end